SignInWithFirebaseButton class

Sign in with Firebase button. When pressed, attempts to sign in with Firebase.

Inheritance

Constructors

SignInWithFirebaseButton({Key? key, required Caller caller, required List<AuthProvider<AuthListener, AuthCredential>> authProviders, VoidCallback? onSignedIn, VoidCallback? onFailure, ButtonStyle? style, Widget? label, Widget? icon})
Creates a new Sign in with Firebase button.
const

Properties

authProviders → List<AuthProvider<AuthListener, AuthCredential>>
List of Firebase auth provider.
final
caller → Caller
The Auth module's caller.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
The icon widget of the button.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
The label widget of the button.
final
onFailure → VoidCallback?
Called if sign in is unsuccessful.
final
onSignedIn → VoidCallback?
Called if sign in is successful.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → ButtonStyle?
The style of the button.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited